require "sqs_queuer/version"
require 'aws-sdk'
require 'yaml'

module SqsQueuer
  class Queue
    attr_reader :client, :queue_url

    def initialize(queue_url)
      @client = Aws::SQS::Client.new(
        access_key_id: ENV['AWS_KEY_ID'],
        secret_access_key: ENV['AWS_SECRET_ACCESS_KEY']
      )
      @queue_url = queue_url
    end

    def add_to_queue(body)
      body = YAML::dump(body)

      client.send_message({
        queue_url: queue_url,
        message_body: body
      })
    end

    def pull_from_queue
      resp = client.receive_message({
        queue_url: queue_url,
        max_number_of_messages: 1
      })

      if resp.messages[0]
        message = resp.messages[0]
        client.delete_message(queue_url: queue_url, receipt_handle: message.receipt_handle)
        YAML::load(message.body)
      end
    end
  end
end
